@@ -77,9 +77,9 @@ class MachineSet(NamespacedResource):
         self.machine_type = machine_type
         self.provider_spec = provider_spec or {}
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             _spec, _metadata, _labels = ("spec", "metadata", "labels")
             (
                 _cluster_api_cluster,
